==> antos0.44.tar.gz: antos0.44/lock.h <==
/*
 * lock.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef lock_h
#define lock_h


#include<proc.h>
#include<lib.h>
#include<console.h>
#include<limits.h>


#ifndef ASM_FILE


// åѹ¤
typedef struct{
	int volatile gate;		// ȹѥԥå
	int volatile count;		// 
}MODIFY_LOCK;


// ԥå
extern inline void enter_spinlock(int volatile *gate)
{
	int rest;

	for(;;){
		while (*gate == 1){;
		}
		asm volatile(
			"movl	$1,%%eax\n"
			"xchgl	%%eax,(%%edx)"
			:"=a"(rest):"d"(gate)
		);
		if (rest == 0){
			break;
		}
	}
}


// ԥåФ
extern inline void exit_spinlock(int volatile *gate)
{
	*gate=0;
}


extern inline void cli()
{
	asm volatile("cli");
}


extern inline void sti()
{
	asm volatile("sti");
}

extern void enterCli(int*);
extern void exitCli(int*);
extern void lockModify(MODIFY_LOCK *modifyLock);
extern void unlockModify(MODIFY_LOCK *modifyLock);
extern void countUpModify(MODIFY_LOCK *modifyLock);
extern void countDownModify(MODIFY_LOCK *modifyLock);


/*
 * Atomic set 1
 * parameters : Gate
 * returns : not set 0,already set 1
 */
/*extern inline int atomic_set(int *gate)
{
	int rest;

	asm volatile(
		"movl	$1,%%eax\n"
		"xchgl	%%eax,(%%edx)"
		:"=a"(rest):"d"(gate)
	);

	return rest;
}
*/

/*
 * ¾å
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣),Ǿɤ߹楫
 */
/*extern inline void enterWriteLock(SHARE_LOCK volatile *share,int count)
{
	int rest;


	for(;;)
	{
		for(;;)
		{
			while(share->gate==1);
			asm volatile(
				"movl	$1,%%eax\n"
				"xchgl	%%eax,(%%edx)"
				:"=a"(rest):"d"(&share->gate)
			);
			if(rest==0)break;
		}

		if(share->count<=count)break;

		share->gate=0;
	}
}
*/

/*
 * ɹѶͭå
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void enterReadLock(SHARE_LOCK volatile *share)
{
	int rest;


	for(;;)
	{
		while(share->gate==1);
		asm volatile(
			"movl	$1,%%eax\n"
			"xchgl	%%eax,(%%edx)"
			:"=a"(rest):"d"(&share->gate)
		);
		if(rest==0)break;
	}

	++share->count;
	share->gate=0;
}
*/

/*
 * ¾åФ
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void exitWriteLock(SHARE_LOCK volatile *share)
{
	share->gate=0;
}
*/

/*
 * ɹѶͭåФ
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void exitReadLock(SHARE_LOCK volatile *share)
{
	--share->count;
}
*/

/*
 * ߥå
 * ߥե饰¸ƳԲĤꤹ
 * parameters : ߲ĥե饰¸Хåե
 */
/*extern inline void enter_intrlock(int *iflag)
{
	asm volatile(
		"pushfl\n"
		"popl	%%eax\n"
		"cli"
		:"=a"(*iflag):
	);
	*iflag&=0x200;
}*/


/*
 * ߥå
 * ¸Ƥߥե饰
 * parameters : ߲ĥե饰¸Хåե
 */
/*extern inline void exit_intrlock(int *iflag)
{
	asm volatile(
		"pushfl\n"
		"popl	%%edx\n"
		"orl	%%eax,%%edx\n"
		"pushl	%%edx\n"
		"popfl"
		::"a"(*iflag)
	);
}*/


#endif


#endif

==> antos0.45.tar.gz: antos0.45/lock.h <==
/*
 * lock.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef lock_h
#define lock_h


#include<proc.h>
#include<lib.h>
#include<console.h>
#include<limits.h>


#ifndef ASM_FILE


// åѹ¤
typedef struct{
	int volatile gate;		// ȹѥԥå
	int volatile count;		// 
}MODIFY_LOCK;


// ԥå
extern inline void enter_spinlock(int volatile *gate)
{
	int rest;

	for(;;){
		while (*gate == 1){;
		}
		asm volatile(
			"movl	$1,%%eax\n"
			"xchgl	%%eax,(%%edx)"
			:"=a"(rest):"d"(gate)
		);
		if (rest == 0){
			break;
		}
	}
}


// ԥåФ
extern inline void exit_spinlock(int volatile *gate)
{
	*gate=0;
}


extern inline void cli()
{
	asm volatile("cli");
}


extern inline void sti()
{
	asm volatile("sti");
}

extern int enterCli();
extern void exitCli(int);
extern void lockModify(MODIFY_LOCK *modifyLock);
extern void unlockModify(MODIFY_LOCK *modifyLock);
extern void countUpModify(MODIFY_LOCK *modifyLock);
extern void countDownModify(MODIFY_LOCK *modifyLock);


/*
 * Atomic set 1
 * parameters : Gate
 * returns : not set 0,already set 1
 */
/*extern inline int atomic_set(int *gate)
{
	int rest;

	asm volatile(
		"movl	$1,%%eax\n"
		"xchgl	%%eax,(%%edx)"
		:"=a"(rest):"d"(gate)
	);

	return rest;
}
*/

/*
 * ¾å
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣),Ǿɤ߹楫
 */
/*extern inline void enterWriteLock(SHARE_LOCK volatile *share,int count)
{
	int rest;


	for(;;)
	{
		for(;;)
		{
			while(share->gate==1);
			asm volatile(
				"movl	$1,%%eax\n"
				"xchgl	%%eax,(%%edx)"
				:"=a"(rest):"d"(&share->gate)
			);
			if(rest==0)break;
		}

		if(share->count<=count)break;

		share->gate=0;
	}
}
*/

/*
 * ɹѶͭå
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void enterReadLock(SHARE_LOCK volatile *share)
{
	int rest;


	for(;;)
	{
		while(share->gate==1);
		asm volatile(
			"movl	$1,%%eax\n"
			"xchgl	%%eax,(%%edx)"
			:"=a"(rest):"d"(&share->gate)
		);
		if(rest==0)break;
	}

	++share->count;
	share->gate=0;
}
*/

/*
 * ¾åФ
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void exitWriteLock(SHARE_LOCK volatile *share)
{
	share->gate=0;
}
*/

/*
 * ɹѶͭåФ
 * parameters : ͭå¤Υɥ쥹staticͤǺǽ0Ƥɬפ롣
 */
/*extern inline void exitReadLock(SHARE_LOCK volatile *share)
{
	--share->count;
}
*/

/*
 * ߥå
 * ߥե饰¸ƳԲĤꤹ
 * parameters : ߲ĥե饰¸Хåե
 */
/*extern inline void enter_intrlock(int *iflag)
{
	asm volatile(
		"pushfl\n"
		"popl	%%eax\n"
		"cli"
		:"=a"(*iflag):
	);
	*iflag&=0x200;
}*/


/*
 * ߥå
 * ¸Ƥߥե饰
 * parameters : ߲ĥե饰¸Хåե
 */
/*extern inline void exit_intrlock(int *iflag)
{
	asm volatile(
		"pushfl\n"
		"popl	%%edx\n"
		"orl	%%eax,%%edx\n"
		"pushl	%%edx\n"
		"popfl"
		::"a"(*iflag)
	);
}*/


#endif


#endif
